<?php

namespace Litecms\Newsservices\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Newsservices\Http\Requests\NewsservicesRequest;
use Litecms\Newsservices\Interfaces\NewsservicesRepositoryInterface;
use Litecms\Newsservices\Models\Newsservices;

/**
 * Resource controller class for newsservices.
 */
class NewsservicesResourceController extends BaseController
{

    /**
     * Initialize newsservices resource controller.
     *
     * @param type NewsservicesRepositoryInterface $newsservices
     *
     * @return null
     */
    public function __construct(NewsservicesRepositoryInterface $newsservices)
    {
        parent::__construct();
        $this->repository = $newsservices;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Newsservices\Repositories\Criteria\NewsservicesResourceCriteria::class);
    }

    /**
     * Display a list of newsservices.
     *
     * @return Response
     */
    public function index(NewsservicesRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Newsservices\Repositories\Presenter\NewsservicesPresenter::class)
                ->$function();
        }

        $newsservices = $this->repository->paginate();

        return $this->response->title(trans('newsservices::newsservices.names'))
            ->view('newsservices::newsservices.index', true)
            ->data(compact('newsservices'))
            ->output();
    }

    /**
     * Display newsservices.
     *
     * @param Request $request
     * @param Model   $newsservices
     *
     * @return Response
     */
    public function show(NewsservicesRequest $request, Newsservices $newsservices)
    {

        if ($newsservices->exists) {
            $view = 'newsservices::newsservices.show';
        } else {
            $view = 'newsservices::newsservices.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('newsservices::newsservices.name'))
            ->data(compact('newsservices'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new newsservices.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(NewsservicesRequest $request)
    {

        $newsservices = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('newsservices::newsservices.name')) 
            ->view('newsservices::newsservices.create', true) 
            ->data(compact('newsservices'))
            ->output();
    }

    /**
     * Create new newsservices.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(NewsservicesRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $newsservices                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('newsservices::newsservices.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('newsservices/newsservices/' . $newsservices->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/newsservices/newsservices'))
                ->redirect();
        }

    }

    /**
     * Show newsservices for editing.
     *
     * @param Request $request
     * @param Model   $newsservices
     *
     * @return Response
     */
    public function edit(NewsservicesRequest $request, Newsservices $newsservices)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('newsservices::newsservices.name'))
            ->view('newsservices::newsservices.edit', true)
            ->data(compact('newsservices'))
            ->output();
    }

    /**
     * Update the newsservices.
     *
     * @param Request $request
     * @param Model   $newsservices
     *
     * @return Response
     */
    public function update(NewsservicesRequest $request, Newsservices $newsservices)
    {
        try {
            $attributes = $request->all();

            $newsservices->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('newsservices::newsservices.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('newsservices/newsservices/' . $newsservices->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('newsservices/newsservices/' . $newsservices->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the newsservices.
     *
     * @param Model   $newsservices
     *
     * @return Response
     */
    public function destroy(NewsservicesRequest $request, Newsservices $newsservices)
    {
        try {

            $newsservices->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('newsservices::newsservices.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('newsservices/newsservices/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('newsservices/newsservices/' . $newsservices->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple newsservices.
     *
     * @param Model   $newsservices
     *
     * @return Response
     */
    public function delete(NewsservicesRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('newsservices::newsservices.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('newsservices/newsservices'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/newsservices/newsservices'))
                ->redirect();
        }

    }

    /**
     * Restore deleted newsservices.
     *
     * @param Model   $newsservices
     *
     * @return Response
     */
    public function restore(NewsservicesRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('newsservices::newsservices.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/newsservices/newsservices'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/newsservices/newsservices/'))
                ->redirect();
        }

    }

}
